@@ -108,6 +108,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"C_groupat", (DL_FUNC) &groupAtVec, 3},
   {"C_funique", (DL_FUNC) &funiqueC, 1},
   {"C_fmatch", (DL_FUNC) &fmatchC, 5},
+  {"C_multi_match", (DL_FUNC) &multi_match, 2},
   {"C_radixsort", (DL_FUNC) &Cradixsort, 6},
   {"C_frankds", (DL_FUNC) &frankds, 4},
   {"C_pacf1", (DL_FUNC) &pacf1, 2},
@@ -125,10 +126,11 @@ static const R_CallMethodDef CallEntries[] = {
   {"C_vecgcd", (DL_FUNC) &vecgcd, 1},
   {"C_issorted", (DL_FUNC) &Cissorted, 2},
   {"C_all_funs", (DL_FUNC) &all_funs, 1},
-  {"C_unlock_collapse_namespace", (DL_FUNC) &unlock_collapse_namespace, 2},
+  {"C_unlock_collapse_namespace", (DL_FUNC) &unlock_collapse_namespace, 1},
   {"C_pivot_long", (DL_FUNC) &pivot_long, 3},
   {"C_pivot_wide", (DL_FUNC) &pivot_wide, 5},
   {"C_sort_merge_join", (DL_FUNC) &sort_merge_join, 4},
+  {"C_replace_outliers", (DL_FUNC) &replace_outliers, 5},
   // {"C_aschar", (DL_FUNC) &CasChar, 1},
   {"C_subsetDT", (DL_FUNC) &subsetDT, 4},
   {"C_subsetVector", (DL_FUNC) &subsetVector, 3},
